@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 from PyQt4 import QtCore, QtGui
-import time
+import time, os
 import zipfile
 
 class Ui_MainWindow(object):
@@ -191,6 +191,7 @@ class Ui_MainWindow(object):
 
     def savePage(self):
         s=str(self.page)
+        os.chmod(0666, "/usr/lib/quran/quran_track.ptr")
 
 	f = open('/usr/lib/quran/quran_track.ptr', "w")
         f.write(s)
